@@ -32,3 +32,17 @@ class Actor(models.Model):
 
     def __str__(self):
         return self.name
+
+
+class Activity(models.Model):
+    device = models.ForeignKey(
+        to='dcim.Device',
+        on_delete=models.PROTECT
+    )
+    actor = models.ManyToManyField(Actor)
+    type = models.CharField(max_length=50, null=False, blank=False)
+    when = models.DateField(default=date.today)
+    description = models.TextField(max_length=255, null=True, blank=True)
+
+    def __str__(self):
+        return self.description
