@@ -16,15 +16,11 @@ Including another URLconf
 
 from django.urls import path
 
-#from .views import  *
+# from .views import  *
 from . import views
 
 urlpatterns = [
-   
-    path('listagem/', views.LisConectividadeView.as_view(), name='list'),
-    #path('list', listagem, name='url_listagem'),
-
-
-
 
+    path('listagem/', views.ListConectividadeView.as_view(), name='list'),
+    # path('list', listagem, name='url_listagem'),
 ]
